@@ -7,15 +7,16 @@ Counter-fitting Word Vectors to Linguistic Constraints.
 """
 import numpy as np
 import os
-from OpenAttack.utils import WordVector, make_zip_downloader
+from OpenAttack.utils import make_zip_downloader
 
 NAME = "AttackAssist.CounterFit"
 
-URL = "https://cdn.data.thunlp.org/TAADToolbox/counter-fitted-vectors.txt.zip"
+URL = "/TAADToolbox/counter-fitted-vectors.txt.zip"
 DOWNLOAD = make_zip_downloader(URL, "counter-fitted-vectors.txt")
 
 
 def LOAD(path):
+    from OpenAttack.attack_assist import WordEmbedding
     with open(os.path.join(path, "counter-fitted-vectors.txt"), "r", encoding='utf-8') as f:
         id2vec = []
         word2id = {}
@@ -28,4 +29,4 @@ def LOAD(path):
             word2id[word] = len(word2id)
             id2vec.append(embed)
         id2vec = np.stack(id2vec)
-    return WordVector(word2id, id2vec)
+    return WordEmbedding(word2id, id2vec)
