@@ -5,5 +5,5 @@
 Dictionary file for ChineseSIMChar substitute.
 """
 NAME = "AttackAssist.SIM"
-DOWNLOAD = "https://cdn.data.thunlp.org/TAADToolbox/sim_dict.pkl"
+DOWNLOAD = "/TAADToolbox/sim_dict.pkl"
 # LOAD = pickle
\ No newline at end of file
