@@ -12,12 +12,13 @@ from OpenAttack.utils import make_zip_downloader
 
 NAME = "Victim.ROBERTA.AG"
 
-URL = "https://cdn.data.thunlp.org/TAADToolbox/victim/roberta_ag.zip"
+URL = "/TAADToolbox/victim/roberta_ag.zip"
 DOWNLOAD = make_zip_downloader(URL)
 
 def LOAD(path):
-    from OpenAttack import HuggingfaceClassifier
     import transformers
     tokenizer = transformers.AutoTokenizer.from_pretrained(path)
     model = transformers.AutoModelForSequenceClassification.from_pretrained(path, num_labels=5, output_hidden_states=False)
-    return HuggingfaceClassifier(model, tokenizer=tokenizer, max_len=100, embedding_layer=model.roberta.embeddings.word_embeddings)
\ No newline at end of file
+
+    from OpenAttack.victim.classifiers import TransformersClassifier
+    return TransformersClassifier(model, tokenizer, model.roberta.embeddings.word_embeddings)
\ No newline at end of file
