@@ -1,11 +1,5 @@
 from .transformers_hook import HookCloser
-from .word_vector import WordVector
-from .functions import check_parameters
 from .zip_downloader import make_zip_downloader
 from .visualizer import visualizer, result_visualizer
-from .nli_wrapper import NLIWrapper
 from .transform_label import update_label
-
-
-from .tf_fix import init_tensorflow
-# init_tensorflow()
\ No newline at end of file
+from .auto_lang import get_language, check_language, language_by_name
